{$I DacDemo.inc}

unit BFile;

interface

uses
{$IFDEF MSWINDOWS}
  Windows, Messages,
{$ENDIF}
{$IFDEF KYLIX}
  SysUtils, Types, Classes, QGraphics, QControls, QForms, QDialogs, QStdCtrls,
  QDBCtrls, QComCtrls, QExtCtrls, QGrids, QDBGrids, QButtons, OdacClx,
{$ELSE}
  SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBCtrls, ExtCtrls, Grids, DBGrids, StdCtrls, ToolWin, ComCtrls, Buttons,
  OdacVcl,
{$ENDIF}
{$IFDEF FPC}
  LResources,
{$ENDIF}
  DB, {$IFNDEF FPC}MemDS{$ELSE}MemDataSet{$ENDIF},
  DBAccess, Ora, OdacDemoFrame, OdacDemoForm;

type
  TBFileFrame = class(TOdacDemoFrame)
    OraQuery: TOraQuery;
    DataSource: TDataSource;
    DBGrid1: TDBGrid;
    DBMemo: TDBMemo;
    ToolBar: TPanel;
    btOpen: TSpeedButton;
    btClose: TSpeedButton;
    DBNavigator: TDBNavigator;
    Splitter1: TSplitter;
    DBGrid: TDBGrid;
    ToolBar1: TPanel;
    btSetFile: TSpeedButton;
    OraQueryCODE: TFloatField;
    OraQueryTITLE: TStringField;
    OraQueryVALUE: TBFileField;
    OraQueryFileName: TStringField;
    btRefresh: TSpeedButton;
    btCreateDirectory: TSpeedButton;
    quCreateDir: TOraQuery;
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    Panel1: TPanel;
    Panel2: TPanel;
    edFileDir: TEdit;
    Label1: TLabel;
    Panel3: TPanel;
    Panel4: TPanel;
    Panel5: TPanel;
    edFileName: TEdit;
    FileName: TLabel;
    Label2: TLabel;
    edDirName: TEdit;
    edDirectory: TEdit;
    Panel6: TPanel;
    Panel7: TPanel;
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure DataSourceDataChange(Sender: TObject; Field: TField);
    procedure btFindClick(Sender: TObject);
    procedure btSetFileClick(Sender: TObject);
    procedure OraQueryCalcFields(DataSet: TDataSet);
    procedure OraQueryAfterScroll(DataSet: TDataSet);
    procedure DBGridDrawDataCell(Sender: TObject; const Rect: TRect;
      Field: TField; State: TGridDrawState);
    procedure btRefreshClick(Sender: TObject);
    procedure btCreateDirectoryClick(Sender: TObject);
  private
    { Private declarations }
  public
    procedure Initialize; override;
    procedure SetDebug(Value: boolean); override;
  end;

implementation
uses
  OraClasses;

{$IFNDEF FPC}
{$IFDEF CLR}
{$R *.nfm}
{$ELSE}
{$R *.dfm}
{$ENDIF}
{$ENDIF}

procedure TBFileFrame.Initialize;
begin
  OraQuery.Connection := Connection;
  quCreateDir.Connection := Connection;
end;

procedure TBFileFrame.btOpenClick(Sender: TObject);
begin
  OraQuery.Open;
end;

procedure TBFileFrame.btCloseClick(Sender: TObject);
begin
  OraQuery.Close;
end;

procedure TBFileFrame.DataSourceDataChange(Sender: TObject; Field: TField);
begin
  edFileDir.Text:= TBFileField(OraQuery.FieldByName('Value')).FileDir;
  edFileName.Text:= TBFileField(OraQuery.FieldByName('Value')).FileName;
end;

procedure TBFileFrame.btFindClick(Sender: TObject);
begin
  if OpenDialog.Execute then
    edFileName.Text:= ExtractFileName(OpenDialog.FileName);
end;

procedure TBFileFrame.btSetFileClick(Sender: TObject);
begin
  if not (OraQuery.State in [dsEdit,dsInsert]) then
    OraQuery.Edit;
  TBFileField(OraQuery.FieldByName('Value')).FileDir:= edFileDir.Text;
  TBFileField(OraQuery.FieldByName('Value')).FileName:= edFileName.Text;
end;

procedure TBFileFrame.OraQueryCalcFields(DataSet: TDataSet);
var
  St:string;
begin
  St:= TBFileField(DataSet.FieldByName('Value')).FileDir + ':' +
    TBFileField(DataSet.FieldByName('Value')).FileName;
  if not TBFileField(DataSet.FieldByName('Value')).Exists then
    St:= St + '  (NoExist)';
  DataSet.FieldByName('FileName').AsString:= St;
end;

procedure TBFileFrame.OraQueryAfterScroll(DataSet: TDataSet);
begin
  edFileDir.Text:= TBFileField(OraQuery.FieldByName('Value')).FileDir;
  edFileName.Text:= TBFileField(OraQuery.FieldByName('Value')).FileName;
end;

procedure TBFileFrame.DBGridDrawDataCell(Sender: TObject; const Rect: TRect;
  Field: TField; State: TGridDrawState);
begin
 with Sender as TDBGrid do begin
   if gdFocused in State then
     Canvas.Brush.Color:= clHighlight
   else
     if (Field = OraQuery.FieldByName('FileName')) and (not TBFileField(OraQuery.FieldByName('Value')).Exists)
     then
       Canvas.Brush.Color := clAqua;

   Canvas.FillRect(Rect);
   Canvas.TextRect(Rect, Rect.Left + 2, Rect.Top + 2, Field.DisplayText);

   if gdFocused in State then
     Canvas.DrawFocusRect(Rect);
 end;
end;

procedure TBFileFrame.btRefreshClick(Sender: TObject);
begin
  TBFileField(OraQuery.FieldByName('Value')).Refresh;
end;

procedure TBFileFrame.btCreateDirectoryClick(Sender: TObject);
begin
  quCreateDir.MacroByName('Name').Value:= edDirName.Text;
  quCreateDir.MacroByName('Dir').AsString:= edDirectory.Text;

  quCreateDir.Execute;
end;

procedure TBFileFrame.SetDebug(Value: boolean);
begin
  OraQuery.Debug := Value;
  quCreateDir.Debug := Value;
end;

initialization
{$IFDEF FPC}
{$I BFile.lrs}
{$ENDIF}

end.
